==> xoonips-3.48.zip: xoonips-3.48/itemtypes/xnpdata/class/xmlrpc/xmlrpctransformcompo.class.php <==
<?php
// $Revision: 1.1.4.1.2.3 $
// ------------------------------------------------------------------------- //
//  XooNIps - Neuroinformatics Base Platform System                          //
//  Copyright (C) 2005-2011 RIKEN, Japan All rights reserved.                //
//  http://xoonips.sourceforge.jp/                                           //
// ------------------------------------------------------------------------- //
//  This program is free software; you can redistribute it and/or modify     //
//  it under the terms of the GNU General Public License as published by     //
//  the Free Software Foundation; either version 2 of the License, or        //
//  (at your option) any later version.                                      //
//                                                                           //
//  You may not change or alter any portion of this comment or credits       //
//  of supporting developers from this source code or any supporting         //
//  source code which is considered copyrighted (c) material of the          //
//  original comment or credit authors.                                      //
//                                                                           //
//  This program is distributed in the hope that it will be useful,          //
//  but WITHOUT ANY WARRANTY; without even the implied warranty of           //
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the            //
//  GNU General Public License for more details.                             //
//                                                                           //
//  You should have received a copy of the GNU General Public License        //
//  along with this program; if not, write to the Free Software              //
//  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA //
// ------------------------------------------------------------------------- //

if ( ! defined( 'XOOPS_ROOT_PATH' ) ) exit();

/**
 *
 * XmlRpcTransform composer class for Data type
 *
 *
 */
class XNPDataXmlRpcTransformCompo extends XooNIpsXmlRpcTransformCompo
{
    function XNPDataXmlRpcTransformCompo() 
    {
        parent::XooNIpsXmlRpcTransformCompo('xnpdata');
    }

    
    /**
     * override getObject to order experimenter.
     * 
     * @see XooNIpsXmlRpcTransformCompo::getObject
     *
     * @param array associative array of XML-RPC argument
     * @return XNPDataOrmExperimenter
     */
    function getObject($in_array) 
    {
        $obj=parent::getObject($in_array);
        $experimenters=&$obj->getVar('experimenter');
        for( $i=0; $i < count($experimenters); $i++){
            $experimenters[$i]->set('experimenter_order', $i);
        }
        return $obj;
    }
}
?>

==> xoonips-3.49.zip: xoonips-3.49/itemtypes/xnpdata/class/xmlrpc/xmlrpctransformcompo.class.php <==
<?php

// ------------------------------------------------------------------------- //
//  XooNIps - Neuroinformatics Base Platform System                          //
//  Copyright (C) 2005-2011 RIKEN, Japan All rights reserved.                //
//  http://xoonips.sourceforge.jp/                                           //
// ------------------------------------------------------------------------- //
//  This program is free software; you can redistribute it and/or modify     //
//  it under the terms of the GNU General Public License as published by     //
//  the Free Software Foundation; either version 2 of the License, or        //
//  (at your option) any later version.                                      //
//                                                                           //
//  You may not change or alter any portion of this comment or credits       //
//  of supporting developers from this source code or any supporting         //
//  source code which is considered copyrighted (c) material of the          //
//  original comment or credit authors.                                      //
//                                                                           //
//  This program is distributed in the hope that it will be useful,          //
//  but WITHOUT ANY WARRANTY; without even the implied warranty of           //
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the            //
//  GNU General Public License for more details.                             //
//                                                                           //
//  You should have received a copy of the GNU General Public License        //
//  along with this program; if not, write to the Free Software              //
//  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA //
// ------------------------------------------------------------------------- //

defined('XOOPS_ROOT_PATH') || exit('XOOPS root path not defined');

/**
 * XmlRpcTransform composer class for Data type.
 */
class XNPDataXmlRpcTransformCompo extends XooNIpsXmlRpcTransformCompo
{
    public function __construct()
    {
        parent::__construct('xnpdata');
    }

    /**
     * override getObject to order experimenter.
     *
     * @see XooNIpsXmlRpcTransformCompo::getObject
     *
     * @param array associative array of XML-RPC argument
     *
     * @return XNPDataOrmExperimenter
     */
    public function getObject($in_array)
    {
        $obj = parent::getObject($in_array);
        $experimenters = &$obj->getVar('experimenter');
        for ($i = 0; $i < count($experimenters); ++$i) {
            $experimenters[$i]->set('experimenter_order', $i);
        }

        return $obj;
    }
}
